sqlobject.tests.test_sorting module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_sorting module

class `sqlobject.tests.test_sorting.` `Names`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `firstName`
  `j` = names_table
  property `lastName`
  `q` = names_table
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `defaultOrder` = ['lastName', 'firstName']
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sorting.Names`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'names_table'

`sqlobject.tests.test_sorting.` `firstList`(names)

`sqlobject.tests.test_sorting.` `nameList`(names)

`sqlobject.tests.test_sorting.` `setupNames`()

`sqlobject.tests.test_sorting.` `test_defaultOrder`()

`sqlobject.tests.test_sorting.` `test_otherOrder`()

`sqlobject.tests.test_sorting.` `test_singleUntranslatedColumnOrder`()

`sqlobject.tests.test_sorting.` `test_untranslatedColumnOrder`()